#!/bin/sh
DESTDIR="$(readlink -f "$0" | xargs dirname)"
NAME=$(basename "$DESTDIR")
SOURCE="${SOURCE:-$(spectool --lf "$DESTDIR/$NAME.spec" | grep -E 'Source0?:' | cut -d' ' -f 2 | xargs basename)}"
SRCDIR="${SRCDIR:-$(basename "$SOURCE" .tar.gz)}"
WORKDIR=${WORKDIR:-$(mktemp -d)}

die() { echo "$@"; exit 1; }

cat <<EOF
Generating vendored dependency archive for "$NAME"
Working directory: $WORKDIR
Source archive:    $SOURCE
Source directory:  $SRCDIR
EOF

if [ ! -f "$DESTDIR/$SOURCE" ]; then
    (cd "$DESTDIR" && spectool -g "$DESTDIR/$NAME.spec") || die "Failed to fetch the source file"
fi

if [ -z "$SRCDIR" ] || [ "$SRCDIR" = "$SOURCE" ]; then
    die "Failed to detect the source directory; $SOURCE -> $SRCDIR"
fi

cd "$WORKDIR" || die "Failed to cd to the working directory"

# cleanup
rm -rf "$SRCDIR"

# expand the archive manually; fedpkg prep will run %cargo_prep which we want to avoid
tar xaf "$DESTDIR/$SOURCE"
cd "$SRCDIR" || die "Failed to cd to the source directory"

if [ ! -f Cargo.toml ]; then
    die "Cargo.toml not found at $PWD; something is wrong"
fi

SOURCE_DATE_EPOCH=$(stat --format '%Y' "$DESTDIR/$SOURCE")
export SOURCE_DATE_EPOCH

cargo vendor-filterer \
    --format dir \
    --platform 'aarch64-unknown-linux-gnu' \
    --platform 'x86_64-unknown-linux-gnu' \
    "vendor"

tar caf "$DESTDIR/vendor.tar.xz" vendor
